@@ -2,10 +2,10 @@ package WWW::Translate::interNOSTRUM;
 
 use strict;
 use warnings;
-use WWW::Mechanize;
 use Carp qw(carp croak);
+use WWW::Mechanize;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 my %lang_pairs = (
@@ -24,8 +24,6 @@ my %defaults =   (
                     output => 'plain_text',
                  );
 
-my @fields = ('agent', keys %defaults);
-
 
 sub new {
     my $class = shift;
@@ -47,14 +45,17 @@ sub new {
         }
     }
     
-    # Remove invalid parameters
+    # Replace defaults with overrides
     my %args = (%defaults, %overrides);
     
-    $args{agent} = WWW::Mechanize->new();
-    
+    # Remove invalid parameters
+    my @fields = keys %defaults;
     my %this;
     @this{@fields} = @args{@fields};
     
+    $this{agent} = WWW::Mechanize->new();
+    $this{url} = 'http://www.internostrum.com/welcome.php'; 
+    
     return bless(\%this, $class);
 }
 
@@ -71,22 +72,18 @@ sub translate {
     
     return '' if ($string eq '');
 
-    # interNOSTRUM url
-    my $url = 'http://www.internostrum.com/welcome.php';
-    
     my $mech = $self->{agent};
     
-    $mech->get($url);
+    $mech->get($self->{url});
     croak $mech->response->status_line unless $mech->success;
     
-    $mech->field("quadretext", $string);  
+    $mech->field("quadretext", $string);
     
     if ($self->{lang_pair} eq 'es-va') {
         $self->{lang_pair} = 'es-ca';
         $mech->tick('valen', 1);
     }
     $mech->select("direccio", $self->{lang_pair});  
-    
     $mech->select("tipus", $output{$self->{output}});
     
     $mech->click();
@@ -100,10 +97,9 @@ sub translate {
     }
             
     # remove double spaces
-    $translated =~ s/(\S)\s{2}(\S)/$1 $2/g;
-        
-    return $translated;
+    $translated =~ s/(?<=\S)\s{2}(?=\S)/ /g;
     
+    return $translated;
 }
 
 sub from_into {
@@ -115,7 +111,6 @@ sub from_into {
     } else {
         return $self->{lang_pair};
     }
-    
 }
 
 sub output_format {
@@ -151,12 +146,13 @@ WWW::Translate::interNOSTRUM - Catalan < > Spanish machine translation
 
 =head1 VERSION
 
-Version 0.02 November 7, 2006
+Version 0.03 November 13, 2006
 
 
 =head1 SYNOPSIS
 
-    use WWW::Translate::interNOSTRUM; 
+    use WWW::Translate::interNOSTRUM;
+    
     my $engine = WWW::Translate::interNOSTRUM->new();
     
     my $translated_string = $engine->translate($string);
@@ -186,9 +182,9 @@ web server.
 interNOSTRUM provides approximate translations of Catalan into Spanish and
 Spanish into Catalan. It generates both the central variant of Oriental
 Catalan (the standard variant used in Catalonia) and, optionally,
-Valencian forms, which follow the recommendations published in the guide
+Valencian forms, which follow the recommendations published in 
 L<http://www.ua.es/spv/assessorament/criteris.pdf>.
-For more information on the Catalan variants, please see the References
+For more information on the Catalan variants, see the References
 below.
 
 
@@ -211,22 +207,20 @@ The valid values of this parameter are:
 
 =over 8
 
+=item * C<< ca-es >>
+
+Standard Catalan or Valencian into Spanish (default value).
+
 =item * C<< es-ca >>
 
-Spanish into Standard Catalan
+Spanish into Standard Catalan.
 
 =item * C<< es-va >>
 
-Spanish into Valencian
-
-=item * C<< ca-es >>
-
-Standard Catalan or Valencian into Spanish
+Spanish into Valencian.
 
 =back
 
-Default value: 'ca-es'.
-
 
 =item * C<< output >>
 
@@ -236,7 +230,7 @@ The valid values of this parameter are:
 
 =item * C<< plain_text >>
 
-Returns the translation as plain text.
+Returns the translation as plain text (default value).
 
 =item * C<< marked_text >>
 
@@ -244,7 +238,6 @@ Returns the translation with the unknown words marked with an asterisk.
 
 =back
 
-Default value: 'plain_text'
 
 =back
 
@@ -256,6 +249,7 @@ interNOSTRUM engine object:
                     lang_pair => 'es-ca',
                     output => 'marked_text',
                   );
+
     my $engine = WWW::Translate::interNOSTRUM->new(%options);
 
                                                     
@@ -266,8 +260,9 @@ interNOSTRUM engine object:
 
 Returns the translation of $string generated by interNOSTRUM.
 $string must be a string of ANSI text, and can contain up to 16,384 characters.
-If the encoding of the source text isn't Latin-1, you must convert it to Latin-1
-before sending it to the MT engine. You can use the Encode module for this task.
+If the source text isn't encoded as Latin-1, you must convert it to Latin-1
+before sending it to the MT engine. For this task you can use the Encode module
+or the PerlIO layer, if you are reading the text from a file.
 
 
 =head2 $engine->from_into($lang_pair)
